==> flutter_slick-3.4.7.tar.gz: lib/components/fields/currency.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_slick/navigation/logic.dart';
import 'package:provider/provider.dart';

class DecimalTextInputFormatter extends TextInputFormatter {
  late RegExp _exp;

  DecimalTextInputFormatter({
    int decimalRange = 3,
    bool activatedNegativeValues = true,
  }) : assert(
            decimalRange >= 0, 'DecimalTextInputFormatter declaretion error') {
    var dp = (decimalRange > 0) ? '([.,][0-9]{0,$decimalRange}){0,1}' : '';
    var num = '[0-9]*$dp';
    if (activatedNegativeValues) {
      _exp = RegExp('^((((-){0,1})|((-){0,1}[0-9]$num))){0,1}\$');
    } else {
      _exp = RegExp('^($num){0,1}\$');
    }
  }

  @override
  TextEditingValue formatEditUpdate(
    TextEditingValue oldValue,
    TextEditingValue newValue,
  ) {
    if (_exp.hasMatch(newValue.text)) {
      return newValue;
    }
    return oldValue;
  }
}

class CurrencyField extends StatefulWidget {
  final double? initialValue;
  final bool? enabled;
  final FormFieldValidator<double>? validator;
  final FocusNode? focusNode;
  final TextInputAction? textInputAction;
  final Function()? onEditingComplete;
  final TextEditingController? controller;
  final bool autofocus;
  final String currency;
  final String labelText;
  final void Function(double?) onChanged;

  const CurrencyField({
    super.key,
    this.initialValue,
    this.validator,
    this.enabled,
    this.focusNode,
    this.textInputAction,
    this.onEditingComplete,
    this.controller,
    this.autofocus = false,
    required this.currency,
    required this.labelText,
    required this.onChanged,
  });

  @override
  State<CurrencyField> createState() => _CurrencyFieldState();
}

class _CurrencyFieldState extends State<CurrencyField> {
  double? _parse(String? value) {
    value = value ?? '';
    value = value.replaceAll(',', '.');
    return double.tryParse(value);
  }

  late TextEditingController controller;

  @override
  void initState() {
    super.initState();
    controller = widget.controller ?? TextEditingController();
    controller.addListener(() {
      if (_parse(controller.text) != widget.initialValue) {
        Provider.of<NavigationLogic>(context, listen: false).setDirty();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    var validator = widget.validator;
    return TextFormField(
      initialValue: widget.initialValue?.toString() ?? '',
      controller: controller,
      validator: validator == null ? null : (v) => validator(_parse(v)),
      enabled: widget.enabled,
      keyboardType: const TextInputType.numberWithOptions(decimal: true),
      inputFormatters: [DecimalTextInputFormatter()],
      decoration: InputDecoration(
        labelText: widget.labelText,
        prefixText: widget.currency,
      ),
      autofocus: widget.autofocus,
      focusNode: widget.focusNode,
      onChanged: (v) => widget.onChanged(_parse(v)),
      textInputAction: widget.textInputAction,
      onEditingComplete: widget.onEditingComplete,
    );
  }
}

==> flutter_slick-3.4.13.tar.gz: lib/components/fields/currency.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_slick/navigation/logic.dart';
import 'package:provider/provider.dart';

class DecimalTextInputFormatter extends TextInputFormatter {
  late RegExp _exp;

  DecimalTextInputFormatter({
    int decimalRange = 3,
    bool activatedNegativeValues = true,
  }) : assert(
            decimalRange >= 0, 'DecimalTextInputFormatter declaretion error') {
    var dp = (decimalRange > 0) ? '([.,][0-9]{0,$decimalRange}){0,1}' : '';
    var num = '[0-9]*$dp';
    if (activatedNegativeValues) {
      _exp = RegExp('^((((-){0,1})|((-){0,1}[0-9]$num))){0,1}\$');
    } else {
      _exp = RegExp('^($num){0,1}\$');
    }
  }

  @override
  TextEditingValue formatEditUpdate(
    TextEditingValue oldValue,
    TextEditingValue newValue,
  ) {
    if (_exp.hasMatch(newValue.text)) {
      return newValue;
    }
    return oldValue;
  }
}

class CurrencyField extends StatefulWidget {
  final double? initialValue;
  final bool? enabled;
  final FormFieldValidator<double>? validator;
  final FocusNode? focusNode;
  final TextInputAction? textInputAction;
  final Function()? onEditingComplete;
  final TextEditingController? controller;
  final bool autofocus;
  final String currency;
  final String labelText;
  final void Function(double?) onChanged;

  const CurrencyField({
    super.key,
    this.initialValue,
    this.validator,
    this.enabled,
    this.focusNode,
    this.textInputAction,
    this.onEditingComplete,
    this.controller,
    this.autofocus = false,
    required this.currency,
    required this.labelText,
    required this.onChanged,
  });

  @override
  State<CurrencyField> createState() => _CurrencyFieldState();
}

class _CurrencyFieldState extends State<CurrencyField> {
  double? _currentValue;
  late FocusNode focusNode;

  double? _parse(String? value) {
    value = value ?? '';
    value = value.replaceAll(',', '.');
    return double.tryParse(value);
  }

  @override
  void initState() {
    super.initState();
    _currentValue = widget.initialValue;
    focusNode = widget.focusNode ?? FocusNode();
    focusNode.addListener(() {
      if (focusNode.hasFocus) return;
      if (_currentValue != widget.initialValue) {
        Provider.of<NavigationLogic>(context, listen: false).setDirty();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    var validator = widget.validator;
    return TextFormField(
      initialValue: widget.initialValue?.toString() ?? '',
      controller: widget.controller,
      validator: validator == null ? null : (v) => validator(_parse(v)),
      enabled: widget.enabled,
      keyboardType: const TextInputType.numberWithOptions(decimal: true),
      inputFormatters: [DecimalTextInputFormatter()],
      decoration: InputDecoration(
        labelText: widget.labelText,
        prefixText: widget.currency,
      ),
      autofocus: widget.autofocus,
      focusNode: widget.focusNode,
      onChanged: (v) {
        _currentValue = _parse(v);
        widget.onChanged(_currentValue);
      },
      textInputAction: widget.textInputAction,
      onEditingComplete: widget.onEditingComplete,
    );
  }
}
